@@ -174,7 +174,7 @@ typedef enum EbSFrameMode {
 } EbSFrameMode;
 
 /* Indicates what prediction structure to use
- * was PredStructure in EbDefinitions.h
+ * was PredStructure in definitions.h
  * Only SVT_AV1_PRED_LOW_DELAY_B and SVT_AV1_PRED_RANDOM_ACCESS are valid
  */
 typedef enum SvtAv1PredStructure {
@@ -739,12 +739,19 @@ typedef struct EbSvtAv1EncConfiguration {
     /* DEPRECATED: to be removed in 1.5.0. */
     int32_t manual_pred_struct_entry_num;
 #endif
+#if OPT_FAST_DECODE_LVLS
+    /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
+    * 0: No decoder speed optimization
+    * -1, 1, 2, 3,..: Decoder speed optimization enabled
+    */
+    int8_t fast_decode;
+#else
     /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
     * 0: No decoder speed optimization
     * 1: Decoder speed optimization enabled (fast decode)
     */
     Bool fast_decode;
-
+#endif
     /* S-Frame interval (frames)
     * 0: S-Frame off
     * >0: S-Frame on and indicates the number of frames after which a frame may be coded as an S-Frame
@@ -936,8 +943,26 @@ typedef struct EbSvtAv1EncConfiguration {
     /* New parameters can go in under this line. Also deduct the size of the parameter */
     /* from the padding array */
 
+    /* Variance boost
+     * false = disable variance boost
+     * true = enable variance boost
+     * Default is false. */
+    Bool enable_variance_boost;
+
+    /* @brief Selects the curve strength to boost low variance regions according to a fast-growing formula
+     * Default is 2 */
+    uint8_t variance_boost_strength;
+
+    /* @brief Picks a set of eight 8x8 variance values per superblock to determine boost
+     * Lower values enable detecting more blocks that need boosting, at the expense of more possible false positives (overall bitrate increase)
+     *  1: 1st octile
+     *  4: 4th octile
+     *  8: 8th octile
+     *  Default is 6 */
+    uint8_t variance_octile;
+
     /*Add 128 Byte Padding to Struct to avoid changing the size of the public configuration struct*/
-    uint8_t padding[128];
+    uint8_t padding[128 - sizeof(Bool) - 2 * sizeof(uint8_t)];
 
 } EbSvtAv1EncConfiguration;
 
