@@ -35,21 +35,14 @@
 #include <stdlib.h>
 #include <limits.h>
 #include <new>
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
+
 #include "gtest/gtest.h"
 #include "aom_dsp_rtcd.h"
-#include "EbComputeSAD.h"
-#include "EbMeSadCalculation.h"
-#include "EbMotionEstimation.h"
-#include "EbMotionEstimationContext.h"
-#include "EbTime.h"
+#include "compute_sad.h"
+#include "me_sad_calculation.h"
+#include "motion_estimation.h"
+#include "me_context.h"
+#include "svt_time.h"
 #include "random.h"
 #include "util.h"
 
@@ -449,6 +442,7 @@ class SADTestSubSample
             << avx2_sad << ") error, ref: " << ref_sad;
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(SADTestSubSample);
 
 TEST_P(SADTestSubSample, SADTestSubSample) {
     test_sad_sizes(TEST_BLOCK_SIZES,
@@ -456,13 +450,17 @@ TEST_P(SADTestSubSample, SADTestSubSample) {
     test_sad_size(BlkSize(128, 128));
 }
 
-INSTANTIATE_TEST_CASE_P(
+#ifdef ARCH_X86_64
+
+INSTANTIATE_TEST_SUITE_P(
     SAD, SADTestSubSample,
     ::testing::Combine(
         ::testing::ValuesIn(TEST_PATTERNS),
         ::testing::Values(svt_nxm_sad_kernel_sub_sampled_helper_sse4_1,
                           svt_nxm_sad_kernel_sub_sampled_helper_avx2)));
 
+#endif
+
 /**
  * @brief Unit test for SAD functions include:
  *  - svt_nxm_sad_kernel_helper_c
@@ -525,18 +523,23 @@ class SADTest : public ::testing::WithParamInterface<Testsad_Param_nxm_kernel>,
             << avx2_sad << ") error, ref: " << ref_sad;
     }
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(SADTest);
 
 TEST_P(SADTest, SADTest) {
     test_sad_sizes(TEST_BLOCK_SIZES,
                    sizeof(TEST_BLOCK_SIZES) / sizeof(TEST_BLOCK_SIZES[0]));
 }
 
-INSTANTIATE_TEST_CASE_P(
+#ifdef ARCH_X86_64
+
+INSTANTIATE_TEST_SUITE_P(
     SAD, SADTest,
     ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
                        ::testing::Values(svt_nxm_sad_kernel_helper_sse4_1,
                                          svt_nxm_sad_kernel_helper_avx2)));
 
+#endif
+
 typedef std::tuple<int16_t, int16_t> SearchArea;
 SearchArea TEST_LOOP_AREAS[] = {
     SearchArea(8, 15),    SearchArea(16, 31),   SearchArea(12, 31),
@@ -605,10 +608,12 @@ class sad_LoopTest : public ::testing::WithParamInterface<sad_LoopTestParam>,
 
         Ebsad_LoopKernelNxMType func_c_ = svt_sad_loop_kernel_c;
         Ebsad_LoopKernelNxMType func_o_list[] = {
+#ifdef ARCH_X86_64
             svt_sad_loop_kernel_sse4_1_intrin,
             svt_sad_loop_kernel_avx2_intrin,
 #if EN_AVX512_SUPPORT
             svt_sad_loop_kernel_avx512_intrin
+#endif
 #endif
         };
 
@@ -687,10 +692,12 @@ class sad_LoopTest : public ::testing::WithParamInterface<sad_LoopTestParam>,
 
         Ebsad_LoopKernelNxMType func_c_ = svt_sad_loop_kernel_c;
         Ebsad_LoopKernelNxMType func_o_list[] = {
+#ifdef ARCH_X86_64
             svt_sad_loop_kernel_sse4_1_intrin,
             svt_sad_loop_kernel_avx2_intrin,
 #if EN_AVX512_SUPPORT
             svt_sad_loop_kernel_avx512_intrin
+#endif
 #endif
         };
 
@@ -789,10 +796,11 @@ TEST_P(sad_LoopTest, DISABLED_sad_LoopSpeedTest) {
         sizeof(TEST_BLOCK_SIZES_SMALL) / sizeof(TEST_BLOCK_SIZES_SMALL[0]));
 }
 
-INSTANTIATE_TEST_CASE_P(LOOPSAD, sad_LoopTest,
-                        ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
-                                           ::testing::ValuesIn(TEST_LOOP_AREAS),
-                                           ::testing::Values(0, 1)));
+INSTANTIATE_TEST_SUITE_P(
+    LOOPSAD, sad_LoopTest,
+    ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
+                       ::testing::ValuesIn(TEST_LOOP_AREAS),
+                       ::testing::Values(0, 1)));
 
 /**
  * best_sadmxn in GetEightsad_Test,Allsad_CalculationTest and
@@ -1046,9 +1054,12 @@ class Allsad_CalculationTest
     }
 };
 
+#ifdef ARCH_X86_64
+
 TEST_P(Allsad_CalculationTest, 8x8_16x16_Test_avx2) {
     check_get_8x8_sad(svt_ext_all_sad_calculation_8x8_16x16_avx2);
 }
+
 TEST_P(Allsad_CalculationTest, 8x8_16x16_Test_sse4_1) {
     check_get_8x8_sad(svt_ext_all_sad_calculation_8x8_16x16_sse4_1);
 }
@@ -1059,7 +1070,18 @@ TEST_P(Allsad_CalculationTest, 32x32_64x64_Test_sse4_1) {
 TEST_P(Allsad_CalculationTest, 32x32_64x64_Test_avx2) {
     check_get_32x32_sad(svt_ext_eight_sad_calculation_32x32_64x64_avx2);
 }
-INSTANTIATE_TEST_CASE_P(
+
+#endif
+
+#ifdef ARCH_AARCH64
+
+TEST_P(Allsad_CalculationTest, 8x8_16x16_Test_neon) {
+    check_get_8x8_sad(svt_ext_all_sad_calculation_8x8_16x16_neon);
+}
+
+#endif
+
+INSTANTIATE_TEST_SUITE_P(
     ALLSAD, Allsad_CalculationTest,
     ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
                        ::testing::ValuesIn(TEST_SAD_PATTERNS)));
@@ -1211,6 +1233,8 @@ class Extsad_CalculationTest
             << "compare sad16x16 error sub_sad true";
     }
 
+#ifdef ARCH_X86_64
+
     void check_get_32x32_sad() {
         uint32_t best_sad32x32[2][4];
         uint32_t best_mv32x32[2][4] = {{0}};
@@ -1254,11 +1278,16 @@ class Extsad_CalculationTest
         EXPECT_EQ(0, memcmp(sad_32x32[0], sad_32x32[1], sizeof(sad_32x32[0])))
             << "compare sad_32x32 error";
     }
+
+#endif
 };
 
+#ifdef ARCH_X86_64
+
 TEST_P(Extsad_CalculationTest, Extsad_8x8Test_avx2) {
     check_get_8x8_sad(svt_ext_sad_calculation_8x8_16x16_avx2_intrin);
 }
+
 TEST_P(Extsad_CalculationTest, Extsad_8x8Test_sse4_1) {
     check_get_8x8_sad(svt_ext_sad_calculation_8x8_16x16_sse4_1_intrin);
 }
@@ -1267,11 +1296,23 @@ TEST_P(Extsad_CalculationTest, Extsad_32x32Test) {
     check_get_32x32_sad();
 }
 
-INSTANTIATE_TEST_CASE_P(
+#endif
+
+#ifdef ARCH_AARCH64
+
+TEST_P(Extsad_CalculationTest, Extsad_8x8Test_neon) {
+    check_get_8x8_sad(svt_ext_sad_calculation_8x8_16x16_neon_intrin);
+}
+
+#endif
+
+INSTANTIATE_TEST_SUITE_P(
     EXTSAD, Extsad_CalculationTest,
     ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
                        ::testing::ValuesIn(TEST_SAD_PATTERNS)));
+
 using InitializeBuffer_param_t = ::testing::tuple<uint32_t, uint32_t>;
+
 #define MAX_BUFFER_SIZE 100  // const value to simplify
 class InitializeBuffer32
     : public ::testing::TestWithParam<InitializeBuffer_param_t> {
@@ -1295,6 +1336,7 @@ class InitializeBuffer32
     }
 
   protected:
+#ifdef ARCH_X86_64
     void checkWithSize() {
         svt_initialize_buffer_32bits_c(_ref_, count128, count32, value);
         svt_initialize_buffer_32bits_sse2_intrin(
@@ -1303,6 +1345,7 @@ class InitializeBuffer32
         int cmpResult = memcmp(_ref_, _test_, MAX_BUFFER_SIZE);
         EXPECT_EQ(cmpResult, 0);
     }
+#endif
 
   private:
     uint32_t *_ref_;
@@ -1312,14 +1355,19 @@ class InitializeBuffer32
     uint32_t value;
     SVTRandom rnd_;
 };
+GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(InitializeBuffer32);
+
+#ifdef ARCH_X86_64
 
 TEST_P(InitializeBuffer32, InitializeBuffer) {
     checkWithSize();
 }
 
-INSTANTIATE_TEST_CASE_P(InitializeBuffer32, InitializeBuffer32,
-                        ::testing::Combine(::testing::Values(2, 3, 4),
-                                           ::testing::Values(1, 2, 3)));
+#endif
+
+INSTANTIATE_TEST_SUITE_P(InitializeBuffer32, InitializeBuffer32,
+                         ::testing::Combine(::testing::Values(2, 3, 4),
+                                            ::testing::Values(1, 2, 3)));
 /**
  * @Brief Base class for SAD test. SADTestBasesad_16Bit handle test vector in
  * memory, provide SAD and SAD avg reference function
@@ -1461,6 +1509,7 @@ class SADTestSubSample16bit : public ::testing::WithParamInterface<TestPattern>,
     }
 
   protected:
+#ifdef ARCH_X86_64
     void check_sad(int width, int height) {
         uint32_t repeat = 1;
         if (test_pattern_ == RANDOM) {
@@ -1543,8 +1592,11 @@ class SADTestSubSample16bit : public ::testing::WithParamInterface<TestPattern>,
                 time_c / time_o);
         }
     }
+#endif
 };
 
+#ifdef ARCH_X86_64
+
 BlkSize TEST_BLOCK_SAD_SIZES[] = {
     BlkSize(16, 10),   BlkSize(16, 5),   BlkSize(32, 10), BlkSize(32, 20),
     BlkSize(64, 20),   BlkSize(64, 64),  BlkSize(64, 32), BlkSize(32, 64),
@@ -1565,8 +1617,8 @@ TEST_P(SADTestSubSample16bit, SADTestSubSample16bit) {
         sizeof(TEST_BLOCK_SAD_SIZES) / sizeof(TEST_BLOCK_SAD_SIZES[0]));
 }
 
-INSTANTIATE_TEST_CASE_P(SAD, SADTestSubSample16bit,
-                        ::testing::ValuesIn(TEST_PATTERNS));
+INSTANTIATE_TEST_SUITE_P(SAD, SADTestSubSample16bit,
+                         ::testing::ValuesIn(TEST_PATTERNS));
 
 TEST_P(SADTestSubSample16bit, DISABLED_Speed) {
     speed_sad_sizes(
@@ -1574,6 +1626,7 @@ TEST_P(SADTestSubSample16bit, DISABLED_Speed) {
         sizeof(TEST_BLOCK_SAD_SIZES) / sizeof(TEST_BLOCK_SAD_SIZES[0]));
 }
 
+#endif
 typedef void (*PmeSadLoopKernel)(
     const struct svt_mv_cost_param *mv_cost_params, uint8_t *src,
     uint32_t src_stride, uint8_t *ref, uint32_t ref_stride,
@@ -1627,8 +1680,11 @@ class PmeSadLoopTest
         prepare_data();
 
         PmeSadLoopKernel func_c_ = svt_pme_sad_loop_kernel_c;
-        PmeSadLoopKernel func_o_list[] = {svt_pme_sad_loop_kernel_sse4_1,
-                                          svt_pme_sad_loop_kernel_avx2};
+        PmeSadLoopKernel func_o_list[] = {
+#ifdef ARCH_X86_64
+            svt_pme_sad_loop_kernel_sse4_1, svt_pme_sad_loop_kernel_avx2
+#endif
+        };
 
         mv_cost_params.ref_mv = &ref_mv;
         mv_cost_params.full_ref_mv = {(int16_t)GET_MV_RAWPEL(23),
@@ -1708,6 +1764,8 @@ class PmeSadLoopTest
         }
     }
 
+#ifdef ARCH_X86_64
+
     void speed_sad(int width, int height) {
         const uint64_t num_loop = 100000;
         double time_c, time_o;
@@ -1816,6 +1874,8 @@ class PmeSadLoopTest
                search_area_height_,
                time_c / time_o);
     }
+
+#endif
 };
 
 TEST_P(PmeSadLoopTest, PmeSadLoopTest) {
@@ -1826,6 +1886,8 @@ TEST_P(PmeSadLoopTest, PmeSadLoopTest) {
         sizeof(TEST_BLOCK_SIZES_LARGE) / sizeof(TEST_BLOCK_SIZES_LARGE[0]));
 }
 
+#ifdef ARCH_X86_64
+
 TEST_P(PmeSadLoopTest, DISABLED_PmeSadLoopSpeedTest) {
     speed_sad_sizes(TEST_BLOCK_SIZES,
                     sizeof(TEST_BLOCK_SIZES) / sizeof(TEST_BLOCK_SIZES[0]));
@@ -1834,7 +1896,9 @@ TEST_P(PmeSadLoopTest, DISABLED_PmeSadLoopSpeedTest) {
         sizeof(TEST_BLOCK_SIZES_LARGE) / sizeof(TEST_BLOCK_SIZES_LARGE[0]));
 }
 
-INSTANTIATE_TEST_CASE_P(
+#endif
+
+INSTANTIATE_TEST_SUITE_P(
     PME_LOOPSAD, PmeSadLoopTest,
     ::testing::Combine(::testing::ValuesIn(TEST_PATTERNS),
                        ::testing::ValuesIn(TEST_LOOP_AREAS)));
