@@ -37,11 +37,11 @@
 #include <stdlib.h>
 #include "gtest/gtest.h"
 #include "aom_dsp_rtcd.h"
-#include "EbDefinitions.h"
+#include "definitions.h"
 #include "random.h"
 #include "util.h"
-#include "EbTime.h"
-#include "EbUtility.h"
+#include "svt_time.h"
+#include "utility.h"
 #include "convolve.h"
 #include "filter.h"
 
@@ -74,86 +74,72 @@ using lowbd_convolve_func = void (*)(const uint8_t *src, int src_stride,
                                      const int subpel_y_qn,
                                      ConvolveParams *conv_params);
 
-static const lowbd_convolve_func lowbd_convolve_2d_sr_func_table[] = {
 #ifdef ARCH_X86_64
+static const lowbd_convolve_func lowbd_convolve_2d_sr_func_table[] = {
     svt_av1_convolve_2d_sr_avx2,
     svt_av1_convolve_2d_sr_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_convolve_2d_sr_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_convolve_x_sr_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_convolve_x_sr_avx2,
     svt_av1_convolve_x_sr_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_convolve_x_sr_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_convolve_y_sr_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_convolve_y_sr_avx2,
     svt_av1_convolve_y_sr_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_convolve_y_sr_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_convolve_copy_sr_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_convolve_2d_copy_sr_avx2,
     svt_av1_convolve_2d_copy_sr_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_convolve_2d_copy_sr_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_jnt_convolve_2d_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_jnt_convolve_2d_avx2,
     svt_av1_jnt_convolve_2d_sse2,
     svt_av1_jnt_convolve_2d_ssse3,
 #if EN_AVX512_SUPPORT
     svt_av1_jnt_convolve_2d_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_jnt_convolve_x_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_jnt_convolve_x_avx2,
     svt_av1_jnt_convolve_x_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_jnt_convolve_x_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_jnt_convolve_y_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_jnt_convolve_y_avx2,
     svt_av1_jnt_convolve_y_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_jnt_convolve_y_avx512
 #endif
-#endif  // ARCH_X86_64
 };
 
 static const lowbd_convolve_func lowbd_jnt_convolve_copy_func_table[] = {
-#ifdef ARCH_X86_64
     svt_av1_jnt_convolve_2d_copy_avx2,
     svt_av1_jnt_convolve_2d_copy_sse2,
 #if EN_AVX512_SUPPORT
     svt_av1_jnt_convolve_2d_copy_avx512
 #endif
-#endif  // ARCH_X86_64
 };
+#endif  // ARCH_X86_64
 
 /**
  * @brief Unit test for interpolation in inter prediction:
@@ -830,34 +816,34 @@ TEST_P(AV1LbdJntConvolve2DTest, DISABLED_SpeedTest) {
 
 #ifdef ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(ConvolveTestCOPY, AV1LbdJntConvolve2DTest,
-                        BuildParams(0, 0, 0, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestX, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 0, 0, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY, AV1LbdJntConvolve2DTest,
-                        BuildParams(0, 1, 0, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 1, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY, AV1LbdJntConvolve2DTest,
+                         BuildParams(0, 0, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 0, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY, AV1LbdJntConvolve2DTest,
+                         BuildParams(0, 1, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 1, 0, 0));
 
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D_sse2, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 1, 1, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D_ssse3, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 1, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestX_sse2, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 0, 1, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY_sse2, AV1LbdJntConvolve2DTest,
-                        BuildParams(0, 1, 1, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestCOPY_sse2, AV1LbdJntConvolve2DTest,
-                        BuildParams(0, 0, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_sse2, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 1, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_ssse3, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 1, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_sse2, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 0, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_sse2, AV1LbdJntConvolve2DTest,
+                         BuildParams(0, 1, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY_sse2, AV1LbdJntConvolve2DTest,
+                         BuildParams(0, 0, 1, 0));
 #if EN_AVX512_SUPPORT
-INSTANTIATE_TEST_CASE_P(ConvolveTestCOPY_AVX512, AV1LbdJntConvolve2DTest,
-                        BuildParams(0, 0, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestX_AVX512, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 0, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY_AVX512, AV1LbdJntConvolve2DTest,
-                        BuildParams(0, 1, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D_AVX512, AV1LbdJntConvolve2DTest,
-                        BuildParams(1, 1, 3, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCOPY_AVX512, AV1LbdJntConvolve2DTest,
+                         BuildParams(0, 0, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_AVX512, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 0, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_AVX512, AV1LbdJntConvolve2DTest,
+                         BuildParams(0, 1, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_AVX512, AV1LbdJntConvolve2DTest,
+                         BuildParams(1, 1, 3, 0));
 #endif
 
 #endif  // ARCH_X86_64
@@ -898,32 +884,32 @@ TEST_P(AV1LbdSrConvolve2DTest, DISABLED_SpeedTest) {
 
 #ifdef ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(ConvolveTestCopy, AV1LbdSrConvolve2DTest,
-                        BuildParams(0, 0, 0, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestX, AV1LbdSrConvolve2DTest,
-                        BuildParams(1, 0, 0, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY, AV1LbdSrConvolve2DTest,
-                        BuildParams(0, 1, 0, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D, AV1LbdSrConvolve2DTest,
-                        BuildParams(1, 1, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCopy, AV1LbdSrConvolve2DTest,
+                         BuildParams(0, 0, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX, AV1LbdSrConvolve2DTest,
+                         BuildParams(1, 0, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY, AV1LbdSrConvolve2DTest,
+                         BuildParams(0, 1, 0, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D, AV1LbdSrConvolve2DTest,
+                         BuildParams(1, 1, 0, 0));
 
-INSTANTIATE_TEST_CASE_P(ConvolveTestX_SSE2, AV1LbdSrConvolve2DTest,
-                        BuildParams(1, 0, 1, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY_SSE2, AV1LbdSrConvolve2DTest,
-                        BuildParams(0, 1, 1, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D_SSE2, AV1LbdSrConvolve2DTest,
-                        BuildParams(1, 1, 1, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestCopy_SSE2, AV1LbdSrConvolve2DTest,
-                        BuildParams(0, 0, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_SSE2, AV1LbdSrConvolve2DTest,
+                         BuildParams(1, 0, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_SSE2, AV1LbdSrConvolve2DTest,
+                         BuildParams(0, 1, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_SSE2, AV1LbdSrConvolve2DTest,
+                         BuildParams(1, 1, 1, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCopy_SSE2, AV1LbdSrConvolve2DTest,
+                         BuildParams(0, 0, 1, 0));
 #if EN_AVX512_SUPPORT
-INSTANTIATE_TEST_CASE_P(ConvolveTestCopy_AVX512, AV1LbdSrConvolve2DTest,
-                        BuildParams(0, 0, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestX_AVX512, AV1LbdSrConvolve2DTest,
-                        BuildParams(1, 0, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY_AVX512, AV1LbdSrConvolve2DTest,
-                        BuildParams(0, 1, 2, 0));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D_AVX512, AV1LbdSrConvolve2DTest,
-                        BuildParams(1, 1, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCopy_AVX512, AV1LbdSrConvolve2DTest,
+                         BuildParams(0, 0, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX_AVX512, AV1LbdSrConvolve2DTest,
+                         BuildParams(1, 0, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY_AVX512, AV1LbdSrConvolve2DTest,
+                         BuildParams(0, 1, 2, 0));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D_AVX512, AV1LbdSrConvolve2DTest,
+                         BuildParams(1, 1, 2, 0));
 #endif
 
 #endif  // ARCH_X86_64
@@ -1095,38 +1081,38 @@ TEST_P(AV1HbdJntConvolve2DTest, DISABLED_SpeedTest) {
 
 #ifdef ARCH_X86_64
 
-INSTANTIATE_TEST_CASE_P(SSE41_COPY, AV1HbdJntConvolve2DTest,
-                        BuildParams(0, 0, 1, 1));
-INSTANTIATE_TEST_CASE_P(SSE41_ConvolveTest2D, AV1HbdJntConvolve2DTest,
-                        BuildParams(1, 1, 1, 1));
-INSTANTIATE_TEST_CASE_P(SSE41_ConvolveTestX, AV1HbdJntConvolve2DTest,
-                        BuildParams(1, 0, 1, 1));
-INSTANTIATE_TEST_CASE_P(SSE41_ConvolveTestY, AV1HbdJntConvolve2DTest,
-                        BuildParams(0, 1, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSE41_COPY, AV1HbdJntConvolve2DTest,
+                         BuildParams(0, 0, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSE41_ConvolveTest2D, AV1HbdJntConvolve2DTest,
+                         BuildParams(1, 1, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSE41_ConvolveTestX, AV1HbdJntConvolve2DTest,
+                         BuildParams(1, 0, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSE41_ConvolveTestY, AV1HbdJntConvolve2DTest,
+                         BuildParams(0, 1, 1, 1));
 
-INSTANTIATE_TEST_CASE_P(AVX2_COPY, AV1HbdJntConvolve2DTest,
-                        BuildParams(0, 0, 0, 1));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D, AV1HbdJntConvolve2DTest,
-                        BuildParams(1, 1, 0, 1));
-INSTANTIATE_TEST_CASE_P(ConvolveTestX, AV1HbdJntConvolve2DTest,
-                        BuildParams(1, 0, 0, 1));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY, AV1HbdJntConvolve2DTest,
-                        BuildParams(0, 1, 0, 1));
+INSTANTIATE_TEST_SUITE_P(AVX2_COPY, AV1HbdJntConvolve2DTest,
+                         BuildParams(0, 0, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D, AV1HbdJntConvolve2DTest,
+                         BuildParams(1, 1, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX, AV1HbdJntConvolve2DTest,
+                         BuildParams(1, 0, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY, AV1HbdJntConvolve2DTest,
+                         BuildParams(0, 1, 0, 1));
 
 #endif  // ARCH_X86_64
 
 #ifdef ARCH_AARCH64
 
 // not yet ported
-// INSTANTIATE_TEST_CASE_P(NEON_COPY, AV1HbdJntConvolve2DTest,
+// INSTANTIATE_TEST_SUITE_P(NEON_COPY, AV1HbdJntConvolve2DTest,
 //                         BuildParams(0, 0, 2, 1));
-INSTANTIATE_TEST_CASE_P(NEON_ConvolveTest2D, AV1HbdJntConvolve2DTest,
-                        BuildParams(1, 1, 2, 1));
+INSTANTIATE_TEST_SUITE_P(NEON_ConvolveTest2D, AV1HbdJntConvolve2DTest,
+                         BuildParams(1, 1, 2, 1));
 // not yet ported
-// INSTANTIATE_TEST_CASE_P(NEON_ConvolveTestX, AV1HbdJntConvolve2DTest,
+// INSTANTIATE_TEST_SUITE_P(NEON_ConvolveTestX, AV1HbdJntConvolve2DTest,
 //                         BuildParams(1, 0, 2, 1));
 // not yet ported
-// INSTANTIATE_TEST_CASE_P(NEON_ConvolveTestY, AV1HbdJntConvolve2DTest,
+// INSTANTIATE_TEST_SUITE_P(NEON_ConvolveTestY, AV1HbdJntConvolve2DTest,
 //                         BuildParams(0, 1, 2, 1));
 
 #endif  // ARCH_AARCH64
@@ -1174,23 +1160,23 @@ TEST_P(AV1HbdSrConvolve2DTest, DISABLED_SpeedTest) {
     speed_test();
 }
 
-INSTANTIATE_TEST_CASE_P(SSS3E_ConvolveTestX, AV1HbdSrConvolve2DTest,
-                        BuildParams(1, 0, 1, 1));
-INSTANTIATE_TEST_CASE_P(SSS3E_ConvolveTest2D, AV1HbdSrConvolve2DTest,
-                        BuildParams(1, 1, 1, 1));
-INSTANTIATE_TEST_CASE_P(SSS3E_ConvolveTestY, AV1HbdSrConvolve2DTest,
-                        BuildParams(0, 1, 1, 1));
-INSTANTIATE_TEST_CASE_P(SSS3E_ConvolveTestCopy, AV1HbdSrConvolve2DTest,
-                        BuildParams(0, 0, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSS3E_ConvolveTestX, AV1HbdSrConvolve2DTest,
+                         BuildParams(1, 0, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSS3E_ConvolveTest2D, AV1HbdSrConvolve2DTest,
+                         BuildParams(1, 1, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSS3E_ConvolveTestY, AV1HbdSrConvolve2DTest,
+                         BuildParams(0, 1, 1, 1));
+INSTANTIATE_TEST_SUITE_P(SSS3E_ConvolveTestCopy, AV1HbdSrConvolve2DTest,
+                         BuildParams(0, 0, 1, 1));
 
-INSTANTIATE_TEST_CASE_P(ConvolveTestX, AV1HbdSrConvolve2DTest,
-                        BuildParams(1, 0, 0, 1));
-INSTANTIATE_TEST_CASE_P(ConvolveTest2D, AV1HbdSrConvolve2DTest,
-                        BuildParams(1, 1, 0, 1));
-INSTANTIATE_TEST_CASE_P(ConvolveTestY, AV1HbdSrConvolve2DTest,
-                        BuildParams(0, 1, 0, 1));
-INSTANTIATE_TEST_CASE_P(ConvolveTestCopy, AV1HbdSrConvolve2DTest,
-                        BuildParams(0, 0, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestX, AV1HbdSrConvolve2DTest,
+                         BuildParams(1, 0, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTest2D, AV1HbdSrConvolve2DTest,
+                         BuildParams(1, 1, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestY, AV1HbdSrConvolve2DTest,
+                         BuildParams(0, 1, 0, 1));
+INSTANTIATE_TEST_SUITE_P(ConvolveTestCopy, AV1HbdSrConvolve2DTest,
+                         BuildParams(0, 0, 0, 1));
 
 #endif  // ARCH_X86_64
 
